@@ -1,6 +1,5 @@
 import locale
-import re
-from natural.constant import CONVENTION, ORDINAL_SUFFIX, LARGE_NUMBER_SUFFIX
+from natural.constant import ORDINAL_SUFFIX, LARGE_NUMBER_SUFFIX
 
 
 def _format(value, digits=None):
@@ -46,6 +45,19 @@ def ordinal(value):
     Converts a number to its ordinal representation.
 
     :param value: number
+
+    >>> ordinal(1)
+    u'1st'
+    >>> ordinal(11)
+    u'11th'
+    >>> ordinal(101)
+    u'101st'
+    >>> ordinal(104)
+    u'104th'
+    >>> ordinal(113)
+    u'113th'
+    >>> ordinal(123)
+    u'123rd'
     '''
 
     try:
@@ -65,6 +77,16 @@ def double(value, digits=2):
 
     :param value: number
     :param digits: default ``2``
+
+    >>> double(42)
+    u'42.00'
+    >>> double(42, digits=1)
+    u'42.0'
+    >>> double(12.34)
+    u'12.34'
+    >>> double(1234.56)
+    u'1,234.56'
+
     '''
 
     return unicode(_format(value, digits))
@@ -75,6 +97,16 @@ def number(value):
     Converts a number to a formatted number based on the current locale.
 
     :param value: number
+
+    >>> number(42)
+    u'42'
+    >>> number(12.34)
+    u'12'
+    >>> number(1234)
+    u'1,234'
+    >>> number(1234567)
+    u'1,234,567'
+
     '''
 
     return unicode(_format(value, 0))
@@ -86,6 +118,14 @@ def percentage(value, digits=2):
 
     :param value: number
     :param digits: default ``2``
+
+    >>> percentage(1)
+    u'100.00 %'
+    >>> percentage(0.23, digits=0)
+    u'23 %'
+    >>> percentage(23.421)
+    u'2,342.10 %'
+
     '''
 
     value = float(value) * 100.0
@@ -98,6 +138,12 @@ def word(value, digits=2):
     for that number.
 
     :param value: number
+
+    >>> print word(1)
+    1
+    >>> print word(123456789)
+    123.46 million
+
     '''
 
     convention = locale.localeconv()
